pub struct BoundedSender<T> { /* private fields */ }Expand description
A bounded queue producer that cooperates with cancellation while stalled.
Implementations
Sourceimpl<T> BoundedSender<T>
impl<T> BoundedSender<T>
Sourcepub fn send(
&self,
item: T,
cancellation: &CancellationToken,
) -> Result<(), EngineError>
pub fn send( &self, item: T, cancellation: &CancellationToken, ) -> Result<(), EngineError>
Sends one item, parking while the bounded queue is full.